@@ -4,8 +4,9 @@
 
 from .extract_frames import extract_frames
 
-from .default_videostream import DefaultVideoStream
+from .live_videostream import LiveVideoStream
 
 from .videostream import VideoStream
 
-from .count_frames import count_frames
\ No newline at end of file
+from .frames_and_fps import count_frames
+from .frames_and_fps import get_fps
\ No newline at end of file
